@@ -33,11 +33,11 @@
 
 #define SND_LIB_MAJOR		0
 #define SND_LIB_MINOR		5
-#define SND_LIB_SUBMINOR	1
+#define SND_LIB_SUBMINOR	2
 #define SND_LIB_VERSION		((SND_LIB_MAJOR<<16)|\
 				 (SND_LIB_MINOR<<8)|\
 				  SND_LIB_SUBMINOR)
-#define SND_LIB_VERSION_STR	"0.5.1"
+#define SND_LIB_VERSION_STR	"0.5.2"
 
 /* OBSOLETE DEFINES WHICH WON'T BE IN 0.3.0 FINAL!!! */
 #define SOUNDLIB_VERSION_MAJOR		SND_LIB_MAJOR
@@ -191,7 +191,7 @@ void snd_mixer_sort_eid_name_index(snd_mixer_eid_t *list, int count);
 void snd_mixer_sort_eid_table(snd_mixer_eid_t *list, int count, snd_mixer_weight_entry_t *table);
 void snd_mixer_sort_gid_name_index(snd_mixer_gid_t *list, int count);
 void snd_mixer_sort_gid_table(snd_mixer_gid_t *list, int count, snd_mixer_weight_entry_t *table);
-snd_mixer_weight_entry_t *snd_mixer_default_weights;
+extern snd_mixer_weight_entry_t *snd_mixer_default_weights;
 
 #ifdef __cplusplus
 }
@@ -241,6 +241,8 @@ int snd_pcm_playback_pause(snd_pcm_t *handle, int enable);
 ssize_t snd_pcm_transfer_size(snd_pcm_t *handle, int channel);
 ssize_t snd_pcm_write(snd_pcm_t *handle, const void *buffer, size_t size);
 ssize_t snd_pcm_read(snd_pcm_t *handle, void *buffer, size_t size);
+ssize_t snd_pcm_writev(snd_pcm_t *pcm, const struct iovec *vector, int count);
+ssize_t snd_pcm_readv(snd_pcm_t *pcm, const struct iovec *vector, int count);
 int snd_pcm_mmap(snd_pcm_t *handle, int channel, snd_pcm_mmap_control_t **control, void **buffer);
 int snd_pcm_munmap(snd_pcm_t *handle, int channel);
 
